@@ -49,13 +49,14 @@ class Kather224x224(H5Dataset):
                          target_path=Path(root) / f'{sub_set}.h5',
                          target_key='label',
                          transform=transform,
-                         transform_target=transform_target)
+                         transform_target=transform_target,
+                         num_samples=num_samples)
 
         self.classes = ['ADI', 'BACK', 'DEB', 'LYM', 'MUC', 'MUS', 'NORM', 'STR', 'TUM']
 
     @classmethod
     def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None, num_samples: int = 1):
-        return cls('/data/ldap/histopathologic/processed_read_only/Kather_H5/res224', sub_set, transform, transform_target)
+        return cls('/data/ldap/histopathologic/processed_read_only/Kather_H5/res224', sub_set, transform, transform_target, num_samples=num_samples)
 
     @staticmethod
     def normalization_values():
